﻿using IRaCIS.Core.Domain.Share;
using IRaCIS.Core.Infrastructure;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.Extensions.Localization;
using Microsoft.Extensions.Logging;

namespace IRaCIS.Core.Application.Filter;

public class ProjectExceptionFilter : Attribute, IExceptionFilter
{
    private readonly ILogger<ProjectExceptionFilter> _logger;

    public IStringLocalizer _localizer;

    public ProjectExceptionFilter(IStringLocalizer localizer, ILogger<ProjectExceptionFilter> logger)
    {
        _logger = logger;
        _localizer = localizer;
    }
    public void OnException(ExceptionContext context)
    {
        //context.ExceptionHandled;//记录当前这个异常是否已经被处理过了

        if (!context.ExceptionHandled)
        {
            if (context.Exception.GetType().Name == "DbUpdateConcurrencyException")
            {
                //---并发更新，当前不允许该操作
                context.Result = new JsonResult(ResponseOutput.NotOk(_localizer["ProjectException_ConcurrentUpdateNotAllowed"] + context.Exception.Message));
            }

            if (context.Exception.GetType() == typeof(BusinessValidationFailedException))
            {
                var error = context.Exception as BusinessValidationFailedException;

                var info = string.Empty;

                if (!string.IsNullOrWhiteSpace(error!.LocalizedKey) && StaticData.Log_Locoalize_Dic.ContainsKey(error!.LocalizedKey))
                {
                    info = $"[{error!.LocalizedKey}]:{StaticData.Log_Locoalize_Dic[error!.LocalizedKey]}";
                }


                context.Result = new JsonResult(ResponseOutput.NotOk(context.Exception.Message, "", error!.Code, localizedInfo: info));


                //warning 级别记录
                //_logger.LogWarning($"[{error!.LocalizedKey}]:{StaticData.Log_Locoalize_Dic[error!.LocalizedKey]}");
            }
            else if (context.Exception.GetType() == typeof(QueryBusinessObjectNotExistException))
            {
                context.Result = new JsonResult(ResponseOutput.NotOk(context.Exception.Message, ApiResponseCodeEnum.DataNotExist));
            }
            else
            {
                context.Result = new JsonResult(ResponseOutput.NotOk(_localizer["Project_ExceptionContactDeveloper"] + (context.Exception.InnerException is null ? (context.Exception.Message /*+ context.Exception.StackTrace*/)
                    : (context.Exception.InnerException?.Message /*+ context.Exception.InnerException?.StackTrace*/)), ApiResponseCodeEnum.ProgramException));

                _logger.LogError(context.Exception.InnerException is null ? (context.Exception.Message + context.Exception.StackTrace) : (context.Exception.InnerException?.Message + context.Exception.InnerException?.StackTrace));

            }

            context.ExceptionHandled = true;//标记当前异常已经被处理过了


            //throw new Exception("test-result-exceptioin");

        }
        else
        {
            //继续
        }
    }
}
